@@ -24,6 +24,7 @@ from __future__ import annotations
 import abc
 import collections
 import contextlib
+import importlib
 import logging
 import os
 import shutil
@@ -47,15 +48,20 @@ from molecule.scenario import Scenario
 
 if TYPE_CHECKING:
     from collections.abc import Callable
+    from typing import NoReturn
 
     from molecule.scenario import Scenario
+    from molecule.types import CommandArgs, MoleculeArgs
+
+    ClickCommand = Callable[[Callable[..., None]], click.Command]
+    ClickGroup = Callable[[Callable[..., None]], click.Group]
 
 LOG = logging.getLogger(__name__)
 MOLECULE_GLOB = os.environ.get("MOLECULE_GLOB", "molecule/*/molecule.yml")
 MOLECULE_DEFAULT_SCENARIO_NAME = "default"
 
 
-class Base(metaclass=abc.ABCMeta):
+class Base(abc.ABC):
     """An abstract base class used to define the command interface."""
 
     def __init__(self, c: config.Config) -> None:
@@ -63,9 +69,6 @@ class Base(metaclass=abc.ABCMeta):
 
         Args:
             c: An instance of a Molecule config.
-
-        Returns:
-            None
         """
         self._config = c
         self._setup()
@@ -74,11 +77,11 @@ class Base(metaclass=abc.ABCMeta):
         """Decorate execute from all subclasses."""
         super().__init_subclass__()
         for wrapper in logger.get_section_loggers():
-            cls.execute = wrapper(cls.execute)  # type: ignore  # noqa: PGH003
+            cls.execute = wrapper(cls.execute)  # type: ignore[method-assign]
 
     @abc.abstractmethod
     def execute(
-        self: Base,
+        self,
         action_args: list[str] | None = None,
     ) -> None:  # pragma: no cover
         """Abstract method to execute the command.
@@ -90,15 +93,17 @@ class Base(metaclass=abc.ABCMeta):
     def _setup(self) -> None:
         """Prepare Molecule's provisioner and returns None."""
         self._config.write()
-        self._config.provisioner.write_config()
-        self._config.provisioner.manage_inventory()
+        if self._config.provisioner is not None:
+            self._config.provisioner.write_config()
+            self._config.provisioner.manage_inventory()
 
 
 def execute_cmdline_scenarios(
-    scenario_name: str | None,
-    args: dict[str, Any],
-    command_args: dict[str, Any],
-    ansible_args: tuple[()] | tuple[str] = (),
+    scenario_names: list[str] | None,
+    args: MoleculeArgs,
+    command_args: CommandArgs,
+    ansible_args: tuple[str, ...] = (),
+    excludes: list[str] | None = None,
 ) -> None:
     """Execute scenario sequences based on parsed command-line arguments.
 
@@ -109,25 +114,33 @@ def execute_cmdline_scenarios(
     to generate the scenario(s) configuration.
 
     Args:
-        scenario_name: Name of scenario to run, or ``None`` to run all.
+        scenario_names: Name of scenarios to run, or ``None`` to run all.
         args: ``args`` dict from ``click`` command context
         command_args: dict of command arguments, including the target
         ansible_args: Optional tuple of arguments to pass to the `ansible-playbook` command
-    """
-    glob_str = MOLECULE_GLOB
-    if scenario_name:
-        glob_str = glob_str.replace("*", scenario_name)
-    scenarios = molecule.scenarios.Scenarios(
-        get_configs(args, command_args, ansible_args, glob_str),
-        scenario_name,
-    )
+        excludes: Name of scenarios to not run.
 
-    if scenario_name and scenarios:
-        LOG.info(
-            "%s scenario test matrix: %s",
-            scenario_name,
-            ", ".join(scenarios.sequence(scenario_name)),
-        )
+    Raises:
+        SystemExit: If scenario exits prematurely.
+    """
+    if excludes is None:
+        excludes = []
+
+    configs: list[config.Config] = []
+    if scenario_names is None:
+        configs = [
+            config
+            for config in get_configs(args, command_args, ansible_args, MOLECULE_GLOB)
+            if config.scenario.name not in excludes
+        ]
+    else:
+        # filter out excludes
+        scenario_names = [name for name in scenario_names if name not in excludes]
+        for scenario_name in scenario_names:
+            glob_str = MOLECULE_GLOB.replace("*", scenario_name)
+            configs.extend(get_configs(args, command_args, ansible_args, glob_str))
+
+    scenarios = _generate_scenarios(scenario_names, configs)
 
     for scenario in scenarios:
         if scenario.config.config["prerun"]:
@@ -164,6 +177,36 @@ def execute_cmdline_scenarios(
                 raise
 
 
+def _generate_scenarios(
+    scenario_names: list[str] | None,
+    configs: list[config.Config],
+) -> molecule.scenarios.Scenarios:
+    """Generate Scenarios object from names and configs.
+
+    Args:
+        scenario_names: Names of scenarios to include.
+        configs: List of Config objects to consider.
+
+    Returns:
+        Combined Scenarios object.
+    """
+    scenarios = molecule.scenarios.Scenarios(
+        configs,
+        scenario_names,
+    )
+
+    if scenario_names is not None:
+        for scenario_name in scenario_names:
+            if scenario_name != "*" and scenarios:
+                LOG.info(
+                    "%s scenario test matrix: %s",
+                    scenario_name,
+                    ", ".join(scenarios.sequence(scenario_name)),
+                )
+
+    return scenarios
+
+
 def execute_subcommand(
     current_config: config.Config,
     subcommand_and_args: str,
@@ -173,10 +216,13 @@ def execute_subcommand(
     Args:
         current_config: An instance of a Molecule config.
         subcommand_and_args: A string representing the subcommand and arguments.
+
+    Returns:
+        The result of the subcommand.
     """
     (subcommand, *args) = subcommand_and_args.split(" ")
-    command_module = getattr(molecule.command, subcommand)
-    command = getattr(command_module, text.camelize(subcommand))  # type: ignore[no-untyped-call]
+    command_module = importlib.import_module(f"molecule.command.{subcommand}")
+    command = getattr(command_module, text.camelize(subcommand))
 
     # knowledge of the current action is used by some provisioners
     # to ensure they behave correctly during certain sequence steps,
@@ -203,7 +249,15 @@ def execute_scenario(scenario: Scenario) -> None:
             scenario._remove_scenario_state_directory()  # noqa: SLF001
 
 
-def filter_ignored_scenarios(scenario_paths) -> list[str]:  # type: ignore[no-untyped-def]  # noqa: ANN001, D103
+def filter_ignored_scenarios(scenario_paths: list[str]) -> list[str]:
+    """Filter out candidate scenario paths that are ignored by git.
+
+    Args:
+        scenario_paths: List of candidate scenario paths.
+
+    Returns:
+        Filtered list of scenario paths.
+    """
     command = ["git", "check-ignore", *scenario_paths]
 
     with contextlib.suppress(subprocess.CalledProcessError, FileNotFoundError):
@@ -225,8 +279,8 @@ def filter_ignored_scenarios(scenario_paths) -> list[str]:  # type: ignore[no-un
 
 
 def get_configs(
-    args: dict[str, Any],
-    command_args: dict[str, Any],
+    args: MoleculeArgs,
+    command_args: CommandArgs,
     ansible_args: tuple[str, ...] = (),
     glob_str: str = MOLECULE_GLOB,
 ) -> list[config.Config]:
@@ -251,7 +305,7 @@ def get_configs(
     scenario_paths = filter_ignored_scenarios(scenario_paths)
     configs = [
         config.Config(
-            molecule_file=util.abs_path(c),  # type: ignore[arg-type]
+            molecule_file=util.abs_path(c),
             args=args,
             command_args=command_args,
             ansible_args=ansible_args,
@@ -294,8 +348,12 @@ def _get_subcommand(string: str) -> str:
     return string.split(".")[-1]
 
 
-def click_group_ex():  # type: ignore[no-untyped-def]  # noqa: ANN201
-    """Return extended version of click.group()."""
+def click_group_ex() -> ClickGroup:
+    """Return extended version of click.group().
+
+    Returns:
+        Click command group.
+    """
     # Color coding used to group command types, documented only here as we may
     # decide to change them later.
     # green : (default) as sequence step
@@ -305,7 +363,11 @@ def click_group_ex():  # type: ignore[no-untyped-def]  # noqa: ANN201
         cls=HelpColorsGroup,
         # Workaround to disable click help line truncation to ~80 chars
         # https://github.com/pallets/click/issues/486
-        context_settings={"max_content_width": 9999, "color": should_do_markup()},
+        context_settings={
+            "max_content_width": 9999,
+            "color": should_do_markup(),
+            "help_option_names": ["-h", "--help"],
+        },
         help_headers_color="yellow",
         help_options_color="green",
         help_options_custom_colors={
@@ -321,17 +383,33 @@ def click_group_ex():  # type: ignore[no-untyped-def]  # noqa: ANN201
     )
 
 
-def click_command_ex() -> Callable[[Callable[..., Any]], click.Command]:
-    """Return extended version of click.command()."""
+def click_command_ex(name: str | None = None) -> ClickCommand:
+    """Return extended version of click.command().
+
+    Args:
+        name: A replacement name in the case the automatic one is insufficient.
+
+    Returns:
+        Click command group.
+    """
     return click.command(
         cls=HelpColorsCommand,
+        name=name,
         help_headers_color="yellow",
         help_options_color="green",
     )
 
 
-def result_callback(*args, **kwargs):  # type: ignore[no-untyped-def]  # noqa: ANN002, ANN003, ANN201, ARG001
-    """Click natural exit callback."""
+def result_callback(
+    *args: object,  # noqa: ARG001
+    **kwargs: object,  # noqa: ARG001
+) -> NoReturn:
+    """Click natural exit callback.
+
+    Args:
+        *args: Unused.
+        **kwargs: Unused.
+    """
     # We want to be used we run out custom exit code, regardless if run was
     # a success or failure.
     util.sysexit(0)
