@@ -60,8 +60,9 @@ class Test(base.Base):
 @click.option(
     "--scenario-name",
     "-s",
-    default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
+    multiple=True,
+    default=[base.MOLECULE_DEFAULT_SCENARIO_NAME],
+    help=f"Name of the scenario to target. May be specified multiple times. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
 @click.option(
     "--platform-name",
@@ -81,6 +82,12 @@ class Test(base.Base):
     default=False,
     help="Test all scenarios. Default is False.",
 )
+@click.option(
+    "--exclude",
+    "-e",
+    multiple=True,
+    help="Name of the scenario to exclude from running. May be specified multiple times.",
+)
 @click.option(
     "--destroy",
     type=click.Choice(["always", "never"]),
@@ -95,7 +102,8 @@ class Test(base.Base):
 @click.argument("ansible_args", nargs=-1, type=click.UNPROCESSED)
 def test(  # noqa: PLR0913
     ctx: click.Context,
-    scenario_name: str | None,
+    scenario_name: list[str] | None,
+    exclude: list[str],
     driver_name: str,
     __all: bool,  # noqa: FBT001
     destroy: Literal["always", "never"],
@@ -108,13 +116,14 @@ def test(  # noqa: PLR0913
     Args:
         ctx: Click context object holding commandline arguments.
         scenario_name: Name of the scenario to target.
+        exclude: Name of the scenarios to avoid targeting.
         driver_name: Name of the driver to use.
         __all: Whether molecule should target scenario_name or all scenarios.
         destroy: The destroy strategy to use.
         parallel: Whether the scenario(s) should be run in parallel mode.
         ansible_args: Arguments to forward to Ansible.
         platform_name: Name of the platform to use.
-    """  # noqa: E501
+    """
     args: MoleculeArgs = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
     command_args: CommandArgs = {
@@ -131,4 +140,4 @@ def test(  # noqa: PLR0913
     if parallel:
         util.validate_parallel_cmd_args(command_args)
 
-    base.execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args)
+    base.execute_cmdline_scenarios(scenario_name, args, command_args, ansible_args, exclude)
