@@ -30,10 +30,9 @@ from typing import TYPE_CHECKING
 from uuid import uuid4
 
 from ansible_compat.ports import cache, cached_property
-from packaging.version import Version
 
 from molecule import api, interpolation, platforms, scenario, state, util
-from molecule.app import app
+from molecule.app import get_app
 from molecule.data import __file__ as data_module
 from molecule.dependency import ansible_galaxy, shell
 from molecule.model import schema_v3
@@ -45,10 +44,12 @@ if TYPE_CHECKING:
     from collections.abc import MutableMapping
     from typing import Literal
 
+    from packaging.version import Version
+
     from molecule.dependency.base import Base as Dependency
     from molecule.driver.base import Driver
     from molecule.state import State
-    from molecule.types import CommandArgs, ConfigData, MoleculeArgs
+    from molecule.types import CollectionData, CommandArgs, ConfigData, MoleculeArgs
     from molecule.verifier.base import Verifier
 
 
@@ -74,7 +75,7 @@ def ansible_version() -> Version:
         "molecule.config.ansible_version is deprecated, will be removed in the future.",
         category=DeprecationWarning,
     )
-    return app.runtime.version
+    return get_app(Path()).runtime.version
 
 
 class Config:
@@ -121,7 +122,8 @@ class Config:
             "MOLECULE_PROJECT_DIRECTORY",
             os.getcwd(),  # noqa: PTH109
         )
-        self.runtime = app.runtime
+        self.app = get_app(Path(self.project_directory))
+        self.runtime = self.app.runtime
         self.scenario_path = Path(molecule_file).parent
 
         # Former after_init() contents
@@ -133,20 +135,6 @@ class Config:
         """Write config file to filesystem."""
         util.write_file(self.config_file, util.safe_dump(self.config))
 
-    @property
-    def ansible_collections_path(
-        self,
-    ) -> str:
-        """Return collection path variable for current version of Ansible.
-
-        Returns:
-            The correct ansible collection path to use.
-        """
-        # https://github.com/ansible/ansible/pull/70007
-        if self.runtime.version >= Version("2.10.0.dev0"):
-            return "ANSIBLE_COLLECTIONS_PATH"
-        return "ANSIBLE_COLLECTIONS_PATHS"
-
     @property
     def config_file(self) -> str:
         """Path to the config file.
@@ -231,6 +219,28 @@ class Config:
         """
         return "molecule_parallel" if self.is_parallel else "molecule"
 
+    @property
+    def collection_directory(self) -> Path | None:
+        """Location of collection containing the molecule files.
+
+        Returns:
+            Root of the collection containing the molecule files.
+        """
+        test_paths = [Path.cwd(), Path(self.project_directory)]
+
+        for path in test_paths:
+            if (path / "galaxy.yml").exists():
+                return path
+
+        # Last resort, try to find git root
+        show_toplevel = self.app.run_command("git rev-parse --show-toplevel")
+        if show_toplevel.returncode == 0:
+            path = Path(show_toplevel.stdout.strip())
+            if (path / "galaxy.yml").exists():
+                return path
+
+        return None
+
     @property
     def molecule_directory(self) -> str:
         """Molecule directory for this project.
@@ -240,6 +250,31 @@ class Config:
         """
         return molecule_directory(self.project_directory)
 
+    @cached_property
+    def collection(self) -> CollectionData | None:
+        """Collection metadata sourced from galaxy.yml.
+
+        Returns:
+            A dictionary of information about the collection molecule is running inside, if any.
+        """
+        collection_directory = self.collection_directory
+        if not collection_directory:
+            return None
+
+        galaxy_file = collection_directory / "galaxy.yml"
+        galaxy_data: CollectionData = util.safe_load_file(galaxy_file)
+
+        important_keys = {"name", "namespace"}
+        if missing_keys := important_keys.difference(galaxy_data.keys()):
+            LOG.warning(
+                "The detected galaxy.yml file (%s) is invalid, missing mandatory field %s",
+                galaxy_file,
+                util.oxford_comma(missing_keys),
+            )
+            return None  # pragma: no cover
+
+        return galaxy_data
+
     @cached_property
     def dependency(self) -> Dependency | None:
         """Dependency manager in use.
@@ -266,7 +301,7 @@ class Config:
 
         api_drivers = api.drivers(config=self)
         if driver_name not in api_drivers:
-            msg = f"Failed to find driver {driver_name}. Please ensure that the driver is correctly installed."  # noqa: E501
+            msg = f"Failed to find driver {driver_name}. Please ensure that the driver is correctly installed."
             util.sysexit_with_message(msg)
 
         driver = api_drivers[driver_name]
@@ -348,8 +383,8 @@ class Config:
                 myState.change_state("molecule_yml_date_modified", modTime)
             elif myState.molecule_yml_date_modified != modTime:
                 LOG.warning(
-                    "The scenario config file ('%s') has been modified since the scenario was created. "  # noqa: E501
-                    "If recent changes are important, reset the scenario with 'molecule destroy' to clean up created items or "  # noqa: E501
+                    "The scenario config file ('%s') has been modified since the scenario was created. "
+                    "If recent changes are important, reset the scenario with 'molecule destroy' to clean up created items or "
                     "'molecule reset' to clear current configuration.",
                     self.molecule_file,
                 )
@@ -407,7 +442,7 @@ class Config:
             msg = (
                 f"Driver '{driver_name}' is currently in use but the scenario config "
                 f"has changed and now defines '{driver_from_scenario}'. "
-                "To change drivers, run 'molecule destroy' for converged scenarios or 'molecule reset' otherwise."  # noqa: E501
+                "To change drivers, run 'molecule destroy' for converged scenarios or 'molecule reset' otherwise."
             )
             LOG.warning(msg)
 
